bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD
===========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: WrapToGaussianGammaARD

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGammaARD.__init__
      ~WrapToGaussianGammaARD.add_plate_axis
      ~WrapToGaussianGammaARD.broadcasting_multiplier
      ~WrapToGaussianGammaARD.delete
      ~WrapToGaussianGammaARD.get_mask
      ~WrapToGaussianGammaARD.get_moments
      ~WrapToGaussianGammaARD.get_shape
      ~WrapToGaussianGammaARD.has_plotter
      ~WrapToGaussianGammaARD.lower_bound_contribution
      ~WrapToGaussianGammaARD.move_plates
      ~WrapToGaussianGammaARD.plot
      ~WrapToGaussianGammaARD.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGammaARD.plates
      ~WrapToGaussianGammaARD.plates_multiplier
   
   